@@ -6,8 +6,6 @@ from ..base import CommandBasic
 
 class Command(CommandBasic):
     def handle(self):
-        if self.just_for_debug_mode():
-            return
         apps = set(settings.INSTALLED_APPS)
         for root, dirs, files in os.walk(settings.BASE_DIR):
             for f in files:
